@@ -9,6 +9,12 @@ use {
     std::path::PathBuf,
 };
 
+const DEFAULT_NGINX_LOCATION: &str = "/var/log/nginx";
+static MISSING_DEFAULT_MESSAGE: &str = "\
+No nginx log found at default location, do you have nginx set up?
+If necessary, provide the path to the log file(s) as argument.
+More information with 'rhit --help'.";
+
 fn print_analysis(paths: &[PathBuf], args: &args::Args) -> Result<(), RhitError> {
     let mut log_base = time!("LogBase::new", LogBase::new(paths, args))?;
     let printer = md::Printer::new(args, &log_base);
@@ -23,7 +29,7 @@ pub fn run() -> Result<(), RhitError> {
     let args = Args::parse();
     debug!("args: {:#?}", &args);
     if args.version {
-        println!("dysk {}", env!("CARGO_PKG_VERSION"));
+        println!("{} {}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
     if args.help {
@@ -32,15 +38,20 @@ pub fn run() -> Result<(), RhitError> {
     }
     let mut paths = args.files.clone();
     if paths.is_empty() {
-        paths.push(PathBuf::from("/var/log/nginx"));
+        paths.push(PathBuf::from(DEFAULT_NGINX_LOCATION));
     }
-    match args.output {
-        Output::Raw => print_raw_lines(&paths, &args)?,
-        Output::Tables => print_analysis(&paths, &args)?,
-        Output::Csv => print_csv_lines(&paths, &args)?,
-        Output::Json => print_json_lines(&paths, &args)?,
+    let result = match args.output {
+        Output::Raw => print_raw_lines(&paths, &args),
+        Output::Tables => print_analysis(&paths, &args),
+        Output::Csv => print_csv_lines(&paths, &args),
+        Output::Json => print_json_lines(&paths, &args),
+    };
+    if let Err(RhitError::PathNotFound(ref path)) = result {
+        if path == &PathBuf::from(DEFAULT_NGINX_LOCATION) {
+            eprintln!("{}", MISSING_DEFAULT_MESSAGE);
+        }
     }
     log_mem(Level::Info);
-    Ok(())
+    result
 }
 
